@@ -1,9 +1,8 @@
 #!/bin/sh
 set -e
 
-echo "Running pycodestyle test"
-python3 tests/testmanual_pycodestyle.py || \
-    [ "$IGNORE_PYCODESTYLE" ] || [ "$IGNORE_PEP8" ] 
+echo "Running pre-commit check"
+pre-commit run -a
 
 dpkg-checkbuilddeps -d 'python3-debian, python3-feedparser'
 
@@ -12,7 +11,7 @@ if [ -n "$https_proxy" ]; then
     echo "disabling https_proxy as Python's urllib doesn't support it; see #94130"
     unset https_proxy
 fi
-utils/get_ubuntu_mirrors_from_lp.py > data/templates/Ubuntu.mirrors
+utils/get_ubuntu_mirrors_from_lp.py > data/templates/ubuntu.mirrors
 
 echo "updating Debian mirror list"
-utils/get_debian_mirrors.py > data/templates/Debian.mirrors
+utils/get_debian_mirrors.py > data/templates/debian.mirrors
